@@ -161,7 +161,7 @@ class QNMSettings(QtCore.QSettings):
 	#----------------------------------#
 	def filterSetStopTime( self, stopTime ):
 		self.beginGroup( self.groupFilter )
-		self.setValue(self.key_filterStartTime, stopTime)
+		self.setValue(self.key_filterStopTime, stopTime)
 		self.endGroup()
 
 	def filterGetStopTime(self):
@@ -204,7 +204,7 @@ class QNMSettings(QtCore.QSettings):
 		val = val.toInt()
 		return val[0]
 	
-	def filterRemStopTime(self):
+	def filterRemIfaceType(self):
 		self.beginGroup( self.groupFilter )
 		self.remove( self.key_filterIfcae )
 		self.endGroup()
